==> openjfx_11.0.2+1.orig.tar.xz: openjdk-jfx-11.0.2-1/modules/javafx.web/src/main/native/Source/WebCore/platform/java/SearchPopupMenuJava.h <==
/*
 * Copyright (c) 2011, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

#pragma once

#include "PopupMenuJava.h"
#include "SearchPopupMenu.h"

namespace WebCore {

class SearchPopupMenuJava : public SearchPopupMenu {
public:
    SearchPopupMenuJava(PopupMenuClient*);

    PopupMenu* popupMenu() override;
    void saveRecentSearches(const AtomicString& name, const Vector<RecentSearch>&) override;
    void loadRecentSearches(const AtomicString& name, Vector<RecentSearch>&) override;
    bool enabled() override;

private:
    RefPtr<PopupMenuJava> m_popup;
};

}  // namespace WebCore

==> openjfx_11.0.7+0.orig.tar.xz: openjdk-jfx-11.0.7-0/modules/javafx.web/src/main/native/Source/WebCore/platform/java/SearchPopupMenuJava.h <==
/*
 * Copyright (c) 2011, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

#pragma once

#include "PopupMenuJava.h"
#include <WebCore/SearchPopupMenu.h>
#include <WebCore/PlatformJavaClasses.h>

namespace WebCore {

class SearchPopupMenuJava : public SearchPopupMenu {
public:
    SearchPopupMenuJava(PopupMenuClient*);

    PopupMenu* popupMenu() override;
    void saveRecentSearches(const AtomicString& name, const Vector<RecentSearch>&) override;
    void loadRecentSearches(const AtomicString& name, Vector<RecentSearch>&) override;
    bool enabled() override;

private:
    RefPtr<PopupMenuJava> m_popup;
};

}  // namespace WebCore
